@@ -17,7 +17,9 @@ import System.Directory.Extra
 import System.Exit
 import System.FilePath
 import System.IO
+import System.Process(readProcess)
 import Language.Preprocessor.Cpphs
+import HSE.All(CppFlags(..))
 import Language.Haskell.Exts(defaultParseMode, baseLanguage)
 import Language.Haskell.Exts.Extension
 import Data.Maybe
@@ -36,13 +38,13 @@ getCmd args = withArgs (map f args) $ automatic =<< cmdArgsRun mode
 
 automatic :: Cmd -> IO Cmd
 automatic cmd = case cmd of
-    CmdMain{} -> dataDir $ path $ extension cmd
-    CmdGrep{} -> return $ path $ extension cmd
+    CmdMain{} -> dataDir =<< path =<< git =<< extension cmd
+    CmdGrep{} -> path =<< extension cmd
     CmdTest{} -> dataDir cmd
     _ -> return cmd
     where
-        path cmd = if null $ cmdPath cmd then cmd{cmdPath=["."]} else cmd
-        extension cmd = if null $ cmdExtension cmd then cmd{cmdExtension=["hs","lhs"]} else cmd
+        path cmd = return $ if null $ cmdPath cmd then cmd{cmdPath=["."]} else cmd
+        extension cmd = return $ if null $ cmdExtension cmd then cmd{cmdExtension=["hs","lhs"]} else cmd
         dataDir cmd
             | cmdDataDir cmd  /= "" = return cmd
             | otherwise = do
@@ -51,6 +53,17 @@ automatic cmd = case cmd of
                 if b then return cmd{cmdDataDir=x} else do
                     exe <- getExecutablePath
                     return cmd{cmdDataDir = takeDirectory exe </> "data"}
+        git cmd
+            | cmdGit cmd = do
+                mgit <- findExecutable "git"
+                case mgit of
+                    Nothing -> error "Could not find git"
+                    Just git -> do
+                        let args = ["ls-files", "--cached", "--others", "--exclude-standard"] ++
+                                   map ("*." ++) (cmdExtension cmd)
+                        files <- readProcess git args ""
+                        return cmd{cmdFiles = cmdFiles cmd ++ lines files}
+            | otherwise = return cmd
 
 
 exitWithHelp :: IO a
@@ -59,13 +72,6 @@ exitWithHelp = do
     exitSuccess
 
 
--- | What C pre processor should be used.
-data CppFlags
-    = NoCpp -- ^ No pre processing is done.
-    | CppSimple -- ^ Lines prefixed with @#@ are stripped.
-    | Cpphs CpphsOptions -- ^ The @cpphs@ library is used.
-
-
 -- | When to colour terminal output.
 data ColorMode
     = Never  -- ^ Terminal output will never be coloured.
@@ -84,6 +90,7 @@ data Cmd
         ,cmdReports :: [FilePath]        -- ^ where to generate reports
         ,cmdGivenHints :: [FilePath]     -- ^ which settignsfiles were explicitly given
         ,cmdWithHints :: [String]        -- ^ hints that are given on the command line
+        ,cmdGit :: Bool                  -- ^ use git ls-files to find files
         ,cmdColor :: ColorMode           -- ^ color the result
         ,cmdThreads :: Int              -- ^ Numbmer of threads to use, 0 = whatever GHC has
         ,cmdIgnore :: [String]           -- ^ the hints to ignore
@@ -101,6 +108,7 @@ data Cmd
         ,cmdCppSimple :: Bool
         ,cmdCppAnsi :: Bool
         ,cmdJson :: Bool                -- ^ display hint data as JSON
+        ,cmdCC :: Bool                  -- ^ display hint data as Code Climate Issues
         ,cmdNoSummary :: Bool           -- ^ do not show the summary info
         ,cmdOnly :: [String]            -- ^ specify which hints explicitly
         ,cmdNoExitCode :: Bool
@@ -143,6 +151,7 @@ mode = cmdArgsMode $ modes
         ,cmdReports = nam "report" &= opt "report.html" &= typFile &= help "Generate a report in HTML"
         ,cmdGivenHints = nam "hint" &= typFile &= help "Hint/ignore file to use"
         ,cmdWithHints = nam "with" &= typ "HINT" &= help "Extra hints to use"
+        ,cmdGit = nam "git" &= help "Run on files tracked by git"
         ,cmdColor = nam "colour" &= name "color" &= opt Always &= typ "always/never/auto" &= help "Color output (requires ANSI terminal; auto means on when $TERM is supported; by itself, selects always)"
         ,cmdThreads = 1 &= name "threads" &= name "j" &= opt (0 :: Int) &= help "Number of threads to use (-j for all)"
         ,cmdIgnore = nam "ignore" &= typ "HINT" &= help "Ignore a particular hint"
@@ -160,6 +169,7 @@ mode = cmdArgsMode $ modes
         ,cmdCppSimple = nam_ "cpp-simple" &= help "Use a simple CPP (strip # lines)"
         ,cmdCppAnsi = nam_ "cpp-ansi" &= help "Use CPP in ANSI compatibility mode"
         ,cmdJson = nam_ "json" &= help "Display hint data as JSON"
+        ,cmdCC = nam_ "cc" &= help "Display hint data as Code Climate Issues"
         ,cmdNoSummary = nam_ "no-summary" &= help "Do not show summary information"
         ,cmdOnly = nam "only" &= typ "HINT" &= help "Specify which hints explicitly"
         ,cmdNoExitCode = nam_ "no-exit-code" &= help "Do not give a negative exit if hints"
