@@ -83,13 +83,13 @@ data Classify = Classify
     deriving Show
 
 -- | A @LHS ==> RHS@ style hint rule.
-data HintRule = HintRule
+data HintRule {- PUBLIC -} = HintRule
     {hintRuleSeverity :: Severity -- ^ Default severity for the hint.
     ,hintRuleName :: String -- ^ Name for the hint.
     ,hintRuleScope :: Scope -- ^ Module scope in which the hint operates.
-    ,hintRuleLHS :: Exp_ -- ^ LHS
-    ,hintRuleRHS :: Exp_ -- ^ RHS
-    ,hintRuleSide :: Maybe Exp_ -- ^ Side condition, typically specified with @where _ = ...@.
+    ,hintRuleLHS :: Exp SrcSpanInfo -- ^ LHS
+    ,hintRuleRHS :: Exp SrcSpanInfo -- ^ RHS
+    ,hintRuleSide :: Maybe (Exp SrcSpanInfo) -- ^ Side condition, typically specified with @where _ = ...@.
     ,hintRuleNotes :: [Note] -- ^ Notes about application of the hint.
     }
     deriving Show
