@@ -39,6 +39,7 @@ module Hint.Naming(namingHint) where
 
 import Hint.Type
 import Data.List
+import Data.Data
 import Data.Char
 import Data.Maybe
 import qualified Data.Set as Set
@@ -59,7 +60,7 @@ shorten x = case x of
     PatBind a b c _ -> f (PatBind a b) c
     x -> x
     where
-        dots = Var an $ UnQual an $ Ident an "..." -- Must be an Ident, not a Symbol
+        dots = Var an ellipses
         f cont (UnGuardedRhs _ _) = cont (UnGuardedRhs an dots) Nothing
         f cont (GuardedRhss _ _) = cont (GuardedRhss an [GuardedRhs an [Qualifier an dots] dots]) Nothing
 
@@ -102,7 +103,7 @@ suggestName x
         g [] = []
 
 
-replaceNames :: Biplate a (Name S) => [(String,String)] -> a -> a
+replaceNames :: Data a => [(String,String)] -> a -> a
 replaceNames rep = descendBi f
     where f (Ident _ x) = Ident an $ fromMaybe x $ lookup x rep
           f x = x
