@@ -1,6 +1,13 @@
 {-# LANGUAGE RecordWildCards, NoMonomorphismRestriction #-}
 
-module Idea(module Idea, Note(..), showNotes, Severity(..)) where
+module Idea(
+    Idea(..),
+    rawIdea, idea, suggest, warn, ignore,
+    rawIdeaN, suggestN,
+    showIdeasJson, showANSI,
+    Note(..), showNotes,
+    Severity(..)
+    ) where
 
 import Data.List.Extra
 import Data.Char
@@ -26,6 +33,9 @@ data Idea = Idea
     }
     deriving (Eq,Ord)
 
+-- I don't use aeson here for 2 reasons:
+-- 1) Aeson doesn't esape unicode characters, and I want to (allows me to ignore encoding)
+-- 2) I want to control the format so it's slightly human readable as well
 showIdeaJson :: Idea -> String
 showIdeaJson idea@Idea{ideaSpan=srcSpan@SrcSpan{..}, ..} = wrap . intercalate "," . map mkPair $
     [("module", str ideaModule)
@@ -39,7 +49,7 @@ showIdeaJson idea@Idea{ideaSpan=srcSpan@SrcSpan{..}, ..} = wrap . intercalate ",
     ,("endColumn", show srcSpanEndColumn)
     ,("from", str ideaFrom)
     ,("to", maybe "null" str ideaTo)
-    ,("note", show $ map (str . show) ideaNote)
+    ,("note", "[" ++ intercalate "," (map (str . show) ideaNote) ++ "]")
     ,("refactorings", str $ show ideaRefactoring)
     ]
   where
@@ -47,7 +57,8 @@ showIdeaJson idea@Idea{ideaSpan=srcSpan@SrcSpan{..}, ..} = wrap . intercalate ",
         where f '\"' = "\\\""
               f '\\' = "\\\\"
               f '\n' = "\\n"
-              f x | not $ isAscii x = "\\u" ++ takeEnd 4 ("0000" ++ showHex (ord x) "")
+              f '\r' = "\\r"
+              f x | isControl x || not (isAscii x) = "\\u" ++ takeEnd 4 ("0000" ++ showHex (ord x) "")
               f x = [x]
     mkPair (k, v) = show k ++ ":" ++ v
     wrap x = "{" ++ x ++ "}"
@@ -79,14 +90,13 @@ showEx tt Idea{..} = unlines $
 rawIdea = Idea "" ""
 rawIdeaN a b c d e f = Idea "" "" a b c d e f []
 
-idea severity hint from to = rawIdea severity hint (toSrcSpan $ ann from) (f from) (Just $ f to) []
+idea severity hint from to = rawIdea severity hint (srcInfoSpan $ ann from) (f from) (Just $ f to) []
     where f = trimStart . prettyPrint
+
 suggest = idea Suggestion
 warn = idea Warning
+ignore = idea Ignore
 
-
-ideaN severity hint from to = rawIdea severity hint (toSrcSpan $ ann from) (f from) (Just $ f to) [] []
-    where f = trimStart . prettyPrint
+ideaN severity hint from to = idea severity hint from to []
 
 suggestN = ideaN Suggestion
-warnN = ideaN Warning
