@@ -11,14 +11,13 @@ However, this version performs about 10% slower with 2 processors in GHC 6.12.1
 module Parallel(parallel) where
 
 import System.IO.Unsafe
-import GHC.Conc(numCapabilities)
 import Control.Concurrent
 import Control.Exception
 import Control.Monad
 
 
-parallel :: [IO a] -> IO [a]
-parallel = if numCapabilities <= 1 then parallel1 else parallelN
+parallel :: Int -> [IO a] -> IO [a]
+parallel j = if j <= 1 then parallel1 else parallelN j
 
 
 parallel1 :: [IO a] -> IO [a]
@@ -29,12 +28,12 @@ parallel1 (x:xs) = do
     return $ x2:xs2
 
 
-parallelN :: [IO a] -> IO [a]
-parallelN xs = do
+parallelN :: Int -> [IO a] -> IO [a]
+parallelN j xs = do
     ms <- mapM (const newEmptyMVar) xs
     chan <- newChan
     mapM_ (writeChan chan . Just) $ zip ms xs
-    replicateM_ numCapabilities (writeChan chan Nothing >> forkIO (f chan))
+    replicateM_ j (writeChan chan Nothing >> forkIO (f chan))
     let throwE x = throw (x :: SomeException)
     parallel1 $ map (fmap (either throwE id) . takeMVar) ms
     where
